==> cdk-vpc-module-0.0.4.tar.gz: cdk-vpc-module-0.0.4/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-vpc-module",
    "version": "0.0.4",
    "description": "@smallcase/cdk-vpc-module",
    "license": "Apache-2.0",
    "url": "https://github.com/smallcase/cdk-vpc-module.git",
    "long_description_content_type": "text/markdown",
    "author": "Bharat Parmar<bharat.parmar@smallcase.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/smallcase/cdk-vpc-module.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_vpc_module",
        "cdk_vpc_module._jsii"
    ],
    "package_data": {
        "cdk_vpc_module._jsii": [
            "cdk-vpc-module@0.0.4.jsii.tgz"
        ],
        "cdk_vpc_module": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk-lib==2.20.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.54.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk-vpc-module-0.0.5.tar.gz: cdk-vpc-module-0.0.5/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-vpc-module",
    "version": "0.0.5",
    "description": "@smallcase/cdk-vpc-module",
    "license": "Apache-2.0",
    "url": "https://github.com/smallcase/cdk-vpc-module.git",
    "long_description_content_type": "text/markdown",
    "author": "Bharat Parmar<bharat.parmar@smallcase.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/smallcase/cdk-vpc-module.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_vpc_module",
        "cdk_vpc_module._jsii"
    ],
    "package_data": {
        "cdk_vpc_module._jsii": [
            "cdk-vpc-module@0.0.5.jsii.tgz"
        ],
        "cdk_vpc_module": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib==2.62.1",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.74.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
